@@ -7,24 +7,10 @@
 #' but avoids having to temporarily create/allocate a matrix, if only such is
 #' needed only for these calculations.
 #'
-#' @param x An NxK \code{\link[base]{matrix}} or an N * K
-#' \code{\link[base]{vector}}.
-#'
-#' @param idxs,rows,cols A \code{\link[base]{vector}} indicating subset of
-#' elements (or rows and/or columns) to operate over. If
-#' \code{\link[base]{NULL}}, no subsetting is done.
+#' @inheritParams rowAlls
 #'
 #' @param value A value to search for.
 #'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, \code{\link[base]{NA}}s
-#' are excluded first, otherwise not.
-#'
-#' @param dim. An \code{\link[base]{integer}} \code{\link[base]{vector}} of
-#' length two specifying the dimension of \code{x}, also when not a
-#' \code{\link[base]{matrix}}.
-#'
-#' @param ... Not used.
-#'
 #' @return \code{rowCounts()} (\code{colCounts()}) returns an
 #' \code{\link[base]{integer}} \code{\link[base]{vector}} of length N (K).
 #' \code{count()} returns a scalar of type \code{\link[base]{integer}} if
@@ -43,7 +29,7 @@ rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
   } else {
-    stop("Argument 'x' must be a matrix or a vector: ", mode(x)[1L])
+    stop(sprintf("Argument '%s' is not a matrix or a vector: %s", "x", mode(x)[1L]))
   }
 
   # Argument 'dim.':
@@ -51,7 +37,7 @@ rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
 
   # Argument 'value':
   if (length(value) != 1L) {
-    stop("Argument 'value' has to be a single value: ", length(value))
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "value", length(value)))
   }
 
   # Coerce 'value' to matrix
@@ -65,7 +51,8 @@ rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
     has_nas <- TRUE
     counts <- .Call(C_rowCounts, x, dim., rows, cols, value, 2L, na.rm, has_nas)
   } else {
-    if (is.vector(x)) dim(x) <- dim.
+    # Apply new dimensions
+    if (!identical(dim(x), dim.)) dim(x) <- dim.
 
     # Apply subset
     if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
@@ -96,7 +83,7 @@ colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
   } else {
-    stop("Argument 'x' must be a matrix or a vector: ", mode(x)[1L])
+    stop(sprintf("Argument '%s' is not a matrix or a vector: %s", "x", mode(x)[1L]))
   }
 
   # Argument 'dim.':
@@ -104,7 +91,7 @@ colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
 
   # Argument 'value':
   if (length(value) != 1L) {
-    stop("Argument 'value' has to be a single value: ", length(value))
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "value", length(value)))
   }
 
   # Coerce 'value' to matrix
@@ -118,7 +105,8 @@ colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
     has_nas <- TRUE
     counts <- .Call(C_colCounts, x, dim., rows, cols, value, 2L, na.rm, has_nas)
   } else {
-    if (is.vector(x)) dim(x) <- dim.
+    # Apply new dimensions
+    if (!identical(dim(x), dim.)) dim(x) <- dim.
 
     # Apply subset
     if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
@@ -146,12 +134,12 @@ colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
 count <- function(x, idxs = NULL, value = TRUE, na.rm = FALSE, ...) {
   # Argument 'x':
   if (!is.vector(x)) {
-    stop("Argument 'x' must be a vector: ", mode(x)[1L])
+    stop(sprintf("Argument '%s' is not a vector: %s", "x", mode(x)[1L]))
   }
 
   # Argument 'value':
   if (length(value) != 1L) {
-    stop("Argument 'value' has to be a single value: ", length(value))
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "value", length(value)))
   }
 
   # Coerce 'value' to matrix
