@@ -2,19 +2,14 @@
 #'
 #' Estimates quantiles for each row (column) in a matrix.
 #'
+#' @inheritParams rowAlls
+#'
 #' @param x An \code{\link[base]{integer}}, \code{\link[base]{numeric}} or
 #' \code{\link[base]{logical}} NxK \code{\link[base]{matrix}} with N >= 0.
 #'
-#' @param rows,cols A \code{\link[base]{vector}} indicating subset of rows
-#' (and/or columns) to operate over. If \code{\link[base]{NULL}}, no subsetting
-#' is done.
-#'
 #' @param probs A \code{\link[base]{numeric}} \code{\link[base]{vector}} of J
 #' probabilities in [0, 1].
 #'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, \code{\link[base]{NA}}s
-#' are excluded first, otherwise not.
-#'
 #' @param type An \code{\link[base]{integer}} specify the type of estimator.
 #' See \code{\link[stats]{quantile}} for more details.
 #'
@@ -39,20 +34,18 @@ rowQuantiles <- function(x, rows = NULL, cols = NULL,
                          probs = seq(from = 0, to = 1, by = 0.25),
                          na.rm = FALSE, type = 7L, ..., drop = TRUE) {
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Defunct(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
   if (!is.numeric(x) && !is.integer(x) && !is.logical(x)) {
     .Defunct(msg = sprintf("Argument 'x' is of type %s. Only 'integer', 'numeric', and 'logical' is supported.", sQuote(storage.mode(x))))  #nolint
   }
 
   # Argument 'probs':
   if (anyMissing(probs)) {
-    stop("Argument 'probs' contains missing values")
+    stop(sprintf("Argument '%s' must not contain missing values", "probs"))
   }
   eps <- 100 * .Machine$double.eps
   if (any((probs < -eps | probs > 1 + eps))) {
-    stop("Argument 'probs' is out of range [0-eps, 1+eps]")
+    stop(sprintf("Argument '%s' is out of range [0-eps, 1+eps]", "probs"))
   }
 
   # Apply subset
@@ -71,7 +64,7 @@ rowQuantiles <- function(x, rows = NULL, cols = NULL,
 
   # Allocate result
   na_value <- NA_real_
-  storage.mode(na_value) <- storage.mode(x)
+  if (type != 7L) storage.mode(na_value) <- storage.mode(x)
   q <- matrix(na_value, nrow = nrow, ncol = length(probs))
 
   if (nrow > 0L && ncol > 0L) {
@@ -159,20 +152,18 @@ colQuantiles <- function(x, rows = NULL, cols = NULL,
                          probs = seq(from = 0, to = 1, by = 0.25),
                          na.rm = FALSE, type = 7L, ..., drop = TRUE) {
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Defunct(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
   if (!is.numeric(x) && !is.integer(x) && !is.logical(x)) {
     .Defunct(msg = sprintf("Argument 'x' is of type %s. Only 'integer', 'numeric', and 'logical' is supported.", sQuote(storage.mode(x))))  #nolint
   }
 
   # Argument 'probs':
   if (anyMissing(probs)) {
-    stop("Argument 'probs' contains missing values")
+    stop(sprintf("Argument '%s' must not contain missing values", "probs"))
   }
   eps <- 100 * .Machine$double.eps
   if (any((probs < -eps | probs > 1 + eps))) {
-    stop("Argument 'probs' is out of range [0-eps, 1+eps]")
+    stop(sprintf("Argument '%s' is out of range [0-eps, 1+eps]", "probs"))
   }
 
   # Apply subset
@@ -191,7 +182,7 @@ colQuantiles <- function(x, rows = NULL, cols = NULL,
 
   # Allocate result
   na_value <- NA_real_
-  storage.mode(na_value) <- storage.mode(x)
+  if (type != 7L) storage.mode(na_value) <- storage.mode(x)
   q <- matrix(na_value, nrow = ncol, ncol = length(probs))
 
   if (nrow > 0L && ncol > 0L) {
@@ -242,7 +233,6 @@ colQuantiles <- function(x, rows = NULL, cols = NULL,
         }
       }
       
-      storage.mode(q) <- "numeric"
     } else {
       # For each column...
       cols <- seq_len(ncol)
