@@ -6,20 +6,12 @@
 #' memory.  If no weights are given, the corresponding
 #' \code{rowMeans()}/\code{colMeans()} is used.
 #'
-#' @param x A \code{\link[base]{numeric}} NxK \code{\link[base]{matrix}}.
+#' @inheritParams rowAlls
+#' @inheritParams rowDiffs
 #'
 #' @param w A \code{\link[base]{numeric}} \code{\link[base]{vector}} of length
 #' K (N).
 #'
-#' @param rows,cols A \code{\link[base]{vector}} indicating subset of rows
-#' (and/or columns) to operate over. If \code{\link[base]{NULL}}, no subsetting
-#' is done.
-#'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, missing values are
-#' excluded from the calculation, otherwise not.
-#'
-#' @param ... Not used.
-#'
 #' @return Returns a \code{\link[base]{numeric}} \code{\link[base]{vector}} of
 #' length N (K).
 #'
@@ -39,22 +31,20 @@ rowWeightedMeans <- function(x, w = NULL, rows = NULL, cols = NULL,
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Deprecated(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed, and will be defunct (produce an error) in a future version of matrixStats. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
 
   # Argument 'w':
   has_weights <- !is.null(w)
   if (has_weights) {
     n <- ncol(x)
     if (length(w) != n) {
-      stop("The length of argument 'w' is does not match the number of column in 'x': ", length(w), " != ", n)  #nolint
+      stop(sprintf("The length of argument '%s' does not match the number of %s in '%s': %d != %d", "w", "columns", "x", length(w), n))  #nolint
     }
     if (!is.numeric(w)) {
-      stop("Argument 'w' is not numeric: ", mode(w))
+      stop(sprintf("Argument '%s' is not numeric: %s", "w", mode(w)))
     }
     if (any(!is.na(w) & w < 0)) {
-      stop("Argument 'w' has negative weights.")
+      stop(sprintf("Argument '%s' must not contain negative values", "w"))
     }
   }
 
@@ -139,22 +129,20 @@ colWeightedMeans <- function(x, w = NULL,  rows = NULL, cols = NULL,
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Deprecated(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed, and will be defunct (produce an error) in a future version of matrixStats. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
 
   # Argument 'w':
   has_weights <- !is.null(w)
   if (has_weights) {
     n <- nrow(x)
     if (length(w) != n) {
-      stop("The length of argument 'w' is does not match the number of rows in 'x': ", length(w), " != ", n)  #nolint
+      stop(sprintf("The length of argument '%s' does not match the number of %s in '%s': %d != %d", "w", "rows", "x", length(w), n))  #nolint
     }
     if (!is.numeric(w)) {
-      stop("Argument 'w' is not numeric: ", mode(w))
+      stop(sprintf("Argument '%s' is not numeric: %s", "w", mode(w)))
     }
     if (any(!is.na(w) & w < 0)) {
-      stop("Argument 'w' has negative weights.")
+      stop(sprintf("Argument '%s' must not contain negative values", "w"))
     }
   }
 
