@@ -2,23 +2,15 @@
 #'
 #' Computes a weighted MAD of a numeric vector.
 #'
+#' @inheritParams rowAlls
 #'
-#' @param x a \code{\link[base]{numeric}} \code{\link[base]{vector}} containing
-#' the values whose weighted MAD is to be computed.
+#' @param x \code{\link[base]{vector}} of type \code{\link[base]{integer}},
+#' \code{\link[base]{numeric}}, or \code{\link[base]{logical}}.
 #'
 #' @param w a vector of weights the same length as \code{x} giving the weights
 #' to use for each element of \code{x}. Negative weights are treated as zero
 #' weights. Default value is equal weight to all values.
 #'
-#' @param idxs,rows,cols A \code{\link[base]{vector}} indicating subset of
-#' elements (or rows and/or columns) to operate over. If
-#' \code{\link[base]{NULL}}, no subsetting is done.
-#'
-#' @param na.rm a logical value indicating whether \code{\link[base]{NA}}
-#' values in \code{x} should be stripped before the computation proceeds, or
-#' not.  If \code{\link[base]{NA}}, no check at all for \code{\link[base]{NA}}s
-#' is done.  Default value is \code{\link[base]{NA}} (for efficiency).
-#'
 #' @param constant A \code{\link[base]{numeric}} scale factor, cf.
 #' \code{\link[stats]{mad}}.
 #'
@@ -26,8 +18,6 @@
 #' center location of the data.  If \code{\link[base]{NULL}}, it is estimated
 #' from data.
 #'
-#' @param ... Not used.
-#'
 #' @return Returns a \code{\link[base]{numeric}} scalar.
 #'
 #' @example incl/weightedMad.R
@@ -56,20 +46,23 @@ weightedMad <- function(x, w = NULL, idxs = NULL, na.rm = FALSE,
 
   # Argument 'w':
   if (length(w) != n) {
-    stop("The number of elements in arguments 'w' and 'x' does not match: ",
-         length(w), " != ", n)
+    stop(sprintf("The number of elements in arguments '%s' and '%s' does not match: %.0f != %.0f", "w", "x", length(w), n))
   } else if (!is.null(idxs)) {
     # Apply subset on w
     w <- w[idxs]
   }
 
   # Argument 'constant':
-  stopifnot(length(constant) == 1L, is.numeric(constant))
+  if (length(constant) != 1L)
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "constant", length(constant)))
+  if (!is.numeric(constant))
+    stop(sprintf("Argument '%s' is not numeric: %s", "constant", mode(constant)))
 
   # Argument 'center':
-  stopifnot(length(center) <= 1L)
-  
-  
+  if (!is.null(center) && length(center) != 1L)
+    stop(sprintf("Argument '%s' is not a scalar or NULL: %.0f", "center", length(center)))
+
+
   # Apply subset on x
   if (!is.null(idxs)) {
     x <- x[idxs]
@@ -83,7 +76,7 @@ weightedMad <- function(x, w = NULL, idxs = NULL, na.rm = FALSE,
   # Remove values with zero (and negative) weight. This will:
   #  1) take care of the case when all weights are zero,
   #  2) it will most likely speed up the sorting.
-  tmp <- (w > 0)
+  tmp <- (is.na(w) | w > 0)
   if (!all(tmp)) {
     x <- .subset(x, tmp)
     w <- .subset(w, tmp)
@@ -93,7 +86,7 @@ weightedMad <- function(x, w = NULL, idxs = NULL, na.rm = FALSE,
 
   # Drop missing values?
   if (na.rm) {
-    keep <- which(!is.na(x) & !is.na(w))
+    keep <- which(!is.na(x))
     x <- .subset(x, keep)
     w <- .subset(w, keep)
     n <- length(x)
@@ -102,6 +95,9 @@ weightedMad <- function(x, w = NULL, idxs = NULL, na.rm = FALSE,
     return(na_value)
   }
 
+  # Missing values in 'w'?
+  if (anyMissing(w)) return(na_value)
+
   # Are any weights Inf? Then treat them with equal weight and all others
   # with weight zero.
   tmp <- is.infinite(w)
@@ -128,6 +124,9 @@ weightedMad <- function(x, w = NULL, idxs = NULL, na.rm = FALSE,
   # Estimate the mean?
   if (is.null(center)) {
     center <- weightedMedian(x, w = w, na.rm = NA)
+  } else {
+    ## https://github.com/HenrikBengtsson/matrixStats/issues/187
+    centerOnUse("weightedMad")
   }
 
   # Estimate the standard deviation
@@ -148,10 +147,24 @@ rowWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL,
                             na.rm = FALSE,
                             constant = 1.4826, center = NULL, ...) {
   # Argument 'constant':
-  stopifnot(length(constant) == 1L, is.numeric(constant))
-  
-  # Argument 'center':
-  stopifnot(length(center) <= 1L)
+  if (length(constant) != 1L)
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "constant", length(constant)))
+  if (!is.numeric(constant))
+    stop(sprintf("Argument '%s' is not numeric: %s", "constant", mode(constant)))
+
+  # Apply subset on 'center'?
+  if (!is.null(center)) {
+    if (length(center) != nrow(x)) {
+      ## Scalar 'center'?
+      if (length(center) == 1L && is.null(rows)) {
+        validateScalarCenter(center, nrow(x), "rows")
+        center <- rep(center, times = nrow(x))
+      } else {
+        stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "rows", "x", length(center), nrow(x)))
+      }
+    }
+    if (!is.null(rows)) center <- center[rows]
+  }
   
   # Apply subset on x
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
@@ -161,8 +174,18 @@ rowWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL,
   # Apply subset on w
   if (!is.null(w) && !is.null(cols)) w <- w[cols]
 
-  apply(x, MARGIN = 1L, FUN = weightedMad, w = w, na.rm = na.rm,
-        constant = constant, center = center, ...)
+  y <- numeric(nrow(x))
+  for (kk in seq_along(y)) {
+    y[kk] <- weightedMad(x[kk, , drop = TRUE], w = w, na.rm = na.rm,
+                          constant = constant, center = center[kk], ...)
+  }
+
+  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
+  ## when !is.null(center), which is tested by DelayedMatrixStats
+  ## and sparseMatrixStats
+  names(y) <- rownames(x)
+
+  y
 }
 
 
@@ -172,11 +195,26 @@ colWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL,
                             na.rm = FALSE,
                             constant = 1.4826, center = NULL, ...) {
   # Argument 'constant':
-  stopifnot(length(constant) == 1L, is.numeric(constant))
+  if (length(constant) != 1L)
+    stop(sprintf("Argument '%s' is not a scalar: %.0f", "constant", length(constant)))
+  if (!is.numeric(constant))
+    stop(sprintf("Argument '%s' is not numeric: %s", "constant", mode(constant)))
 
   # Argument 'center':
-  stopifnot(length(center) <= 1L)
-  
+  # Apply subset on 'center'?
+  if (!is.null(center)) {
+    if (length(center) != ncol(x)) {
+      ## Scalar 'center'?
+      if (length(center) == 1L && is.null(cols)) {
+        validateScalarCenter(center, ncol(x), "cols")
+        center <- rep(center, times = ncol(x))
+      } else {
+        stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "columns", "x", length(center), ncol(x)))
+      }
+    }
+    if (!is.null(cols)) center <- center[cols]
+  }
+
   # Apply subset on x
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
@@ -185,6 +223,16 @@ colWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL,
   # Apply subset on w
   if (!is.null(w) && !is.null(rows)) w <- w[rows]
 
-  apply(x, MARGIN = 2L, FUN = weightedMad, w = w, na.rm = na.rm,
-        constant = constant, center = center, ...)
+  y <- numeric(ncol(x))
+  for (kk in seq_along(y)) {
+    y[kk] <- weightedMad(x[, kk, drop = TRUE], w = w, na.rm = na.rm,
+                          constant = constant, center = center[kk], ...)
+  }
+
+  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
+  ## when !is.null(center), which is tested by DelayedMatrixStats
+  ## and sparseMatrixStats
+  names(y) <- colnames(x)
+  
+  y
 }
